forms824

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2025 License: MIT Imports: 10 Imported by: 0

README

forms824

Go Reference

a library for website developers on records collection

Why this library?

Some projects needs a lot of forms. Doing the form without this library can take a lot of time though with a lot of perfection.

Where do I create the form description

Use forms814

Dependency

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type F8Object

type F8Object struct {
	FormsPath     string
	FlaarumClient flaarumlib.Client
}

func Init

func Init(formObjectsPath string, cl flaarumlib.Client) (F8Object, error)

creates tables for all formObjects and returns a struct this must be ran before using any other function in this library.

func (*F8Object) GetEditForm

func (f8o *F8Object) GetEditForm(formName string, dataId int64) (string, error)

func (*F8Object) GetNewForm

func (f8o *F8Object) GetNewForm(formName string) (string, error)

func (*F8Object) GetSubmittedData

func (f8o *F8Object) GetSubmittedData(r *http.Request, formName string) (map[string]string, error)

multi_display_select returns a string joined by ';' because this field can have a list as its value

func (*F8Object) ListForms

func (f8o *F8Object) ListForms() ([]string, error)

Directories

Path Synopsis

Jump to