Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type F8Object ¶
type F8Object struct {
FormsPath string
FlaarumClient flaarumlib.Client
}
func Init ¶
func Init(formObjectsPath string, cl flaarumlib.Client) (F8Object, error)
creates tables for all formObjects and returns a struct this must be ran before using any other function in this library.
func (*F8Object) GetEditForm ¶
func (*F8Object) GetSubmittedData ¶
multi_display_select returns a string joined by ';' because this field can have a list as its value
Click to show internal directories.
Click to hide internal directories.